@@ -1,6 +1,6 @@
 __all__ = ['utils', 'types', 'meta', 'lang', 'tree_mini', 'parsing', 'magics',
            'lnsetup', 'display', 'combinators']
 
-__version_info__ = (0, 6, 6)
-__release__ = False
+__version_info__ = (0, 6, 7)
+__release__ = True
 __version__ = ".".join(str(i) for i in __version_info__)
